import Flutter
import UIKit
import Navigine

public class SwiftNavigineSdkPlugin: NSObject, FlutterPlugin, NavigineCoreNavigationDelegate  {
    
    let navigineHelper = NavigineHelper()
    
    static var channel: FlutterMethodChannel? = nil
    
    override init(){
        navigineHelper.setMethodChannel(methodChannel: SwiftNavigineSdkPlugin.channel)
    }
    
    public func navigineCore(_ navigineCore: NavigineCore, didUpdate deviceInfo: NCDeviceInfo) {
        SwiftNavigineSdkPlugin.channel!.invokeMethod("deviceInfo#onUpdate", arguments: Convert.deviceInfo(toObject: deviceInfo));
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        channel = FlutterMethodChannel(name: "navigine_sdk", binaryMessenger: registrar.messenger())
        let instance = SwiftNavigineSdkPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel!)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        let data = call.arguments as! Dictionary<String,Any>?
        switch (call.method) {
        case "initialize":
            let userHash = data!["userHash"] as! String
            let serverUrl = data!["serverUrl"] as! String
            navigineHelper.initilizeSDK(userHash, serverURL: serverUrl)
            result(true)
            break;
        case "loadLocation":
            let locationId = data!["locationId"] as! NSNumber
            navigineHelper.loadLocation(locationId)
            result(true)
            break;
        case "startNavigation":
            navigineHelper.startNavigation()
            result(true)
            break;
        case "stopNavigation":
            navigineHelper.stopNavigation()
            result(true)
            break;
        case "getLocation":
            result(navigineHelper.getLocation());
            break;
        case "getDeviceInfo":
            result(navigineHelper.getDeviceInfo())
            break;
        case "getDeviceInfoStream":
            navigineHelper.setDelegate(deviceInfoDelegate: self)
            result(true);
            break;
        default:
            result(true);
            break;
        }
    }
}
